@@ -1,7 +1,7 @@
 """Key OpenMDAO classes can be imported from here."""
 
 # Core
-from openmdao.core.problem import Problem, slicer
+from openmdao.core.problem import Problem
 from openmdao.core.group import Group
 from openmdao.core.parallel_group import ParallelGroup
 from openmdao.core.explicitcomponent import ExplicitComponent
@@ -56,6 +56,7 @@ from openmdao.surrogate_models.response_surface import ResponseSurface
 from openmdao.surrogate_models.surrogate_model import SurrogateModel, \
     MultiFiSurrogateModel
 
+from openmdao.utils.indexer import slicer
 from openmdao.utils.find_cite import print_citations
 from openmdao.utils.spline_distributions import cell_centered
 from openmdao.utils.spline_distributions import sine_distribution
@@ -97,12 +98,15 @@ from openmdao.utils.notebook_utils import notebook_mode, display_source, show_op
 from openmdao.utils.units import convert_units, unit_conversion
 
 # Warning Options
-from openmdao.warnings import issue_warning, reset_warnings, OpenMDAOWarning, \
+from openmdao.utils.om_warnings import issue_warning, reset_warnings, OpenMDAOWarning, \
     SetupWarning, DistributedComponentWarning, CaseRecorderWarning,\
     DriverWarning, CacheWarning, PromotionWarning, UnusedOptionWarning, DerivativesWarning, \
-    MPIWarning, UnitsWarning, SolverWarning, OMDeprecationWarning
+    MPIWarning, UnitsWarning, SolverWarning, OMDeprecationWarning, \
+    OMInvalidCheckDerivativesOptionsWarning
 
 
+from openmdao.utils.general_utils import wing_dbg
+
 # set up tracing or memory profiling if env vars are set.
 import os
 if os.environ.get('OPENMDAO_TRACE'):
