@@ -4,6 +4,7 @@
 import numpy as np
 
 from openmdao.core.explicitcomponent import ExplicitComponent
+from openmdao.utils.om_warnings import warn_deprecation
 
 
 class DemuxComp(ExplicitComponent):
@@ -34,6 +35,9 @@ class DemuxComp(ExplicitComponent):
 
         self._no_check_partials = True
 
+        warn_deprecation("DemuxComp is being deprecated. This same functionality can be achieved "
+                         "directly in the connect/promotes indices arg using om.slicer.")
+
     def initialize(self):
         """
         Declare options.
