@@ -6,21 +6,22 @@ from contextlib import contextmanager
 import numpy as np
 from numpy import ndarray, imag, complex as npcomplex
 
+from openmdao.core.constants import INT_DTYPE
 from openmdao.core.explicitcomponent import ExplicitComponent
 from openmdao.utils.units import valid_units
-from openmdao.utils.general_utils import warn_deprecation, simple_warning
 from openmdao.utils import cs_safe
+from openmdao.utils.om_warnings import issue_warning, DerivativesWarning, warn_deprecation
 
 # regex to check for variable names.
 VAR_RGX = re.compile(r'([.]*[_a-zA-Z]\w*[ ]*\(?)')
 
 # Names of metadata entries allowed for ExecComp variables.
-_allowed_meta = {'value', 'shape', 'units', 'res_units', 'desc',
+_allowed_meta = {'value', 'val', 'shape', 'units', 'res_units', 'desc',
                  'ref', 'ref0', 'res_ref', 'lower', 'upper', 'src_indices',
                  'flat_src_indices', 'tags', 'shape_by_conn', 'copy_shape'}
 
 # Names that are not allowed for input or output variables (keywords for options)
-_disallowed_names = {'has_diag_partials', 'units', 'shape', 'shape_by_conn'}
+_disallowed_names = {'has_diag_partials', 'units', 'shape', 'shape_by_conn', 'run_root_only'}
 
 
 def check_option(option, value):
@@ -67,6 +68,8 @@ class ExecComp(ExplicitComponent):
         List of expressions.
     _codes : list
         List of code objects.
+    _exprs_info : list
+        List of tuples containing output and inputs for each expression.
     _has_diag_partials : bool
         If True, treat all array/array partials as diagonal if both arrays have size > 1.
         All arrays with size > 1 must have the same flattened size or an exception will be raised.
@@ -160,7 +163,7 @@ class ExecComp(ExplicitComponent):
             Initial values of variables can be set by setting a named
             arg with the var name.  If the value is a dict it is assumed
             to contain metadata.  To set the initial value in addition to
-            other metadata, assign the initial value to the 'value' entry
+            other metadata, assign the initial value to the 'val' entry
             of the dict.
 
         Notes
@@ -188,7 +191,7 @@ class ExecComp(ExplicitComponent):
         .. code-block:: python
 
             excomp = ExecComp('y=sum(x)',
-                              x={'value': numpy.ones(10, dtype=float),
+                              x={'val': numpy.ones(10, dtype=float),
                                  'units': 'ft'})
         """
         options = {}
@@ -205,7 +208,8 @@ class ExecComp(ExplicitComponent):
             exprs = [exprs]
 
         self._exprs = exprs[:]
-        self._codes = None
+        self._exprs_info = []
+        self._codes = []
         self._kwargs = kwargs
 
         self._manual_decl_partials = False
@@ -273,11 +277,17 @@ class ExecComp(ExplicitComponent):
         """
         Set up variable name and metadata lists.
         """
+        if self._exprs:
+            self._setup_expressions()
+
+    def _setup_expressions(self):
+        """
+        Set up the expressions.
+
+        This is called during setup_procs and after each call to "add_expr" from configure.
+        """
         global _not_complex_safe
 
-        if not self._exprs:
-            raise RuntimeError("%s: No valid expressions provided to ExecComp(): %s."
-                               % (self.msginfo, self._exprs))
         exprs = self._exprs
         kwargs = self._kwargs
 
@@ -285,6 +295,8 @@ class ExecComp(ExplicitComponent):
         shape = self.options['shape']
         shape_by_conn = self.options['shape_by_conn']
 
+        warned = False
+
         if shape is not None and shape_by_conn:
             raise RuntimeError(f"{self.msginfo}: Can't set both shape and shape_by_conn.")
 
@@ -330,6 +342,17 @@ class ExecComp(ExplicitComponent):
                                        "recognized for variable '%s': %s" %
                                        (self.msginfo, arg, sorted(diff)))
 
+                if 'val' in val and 'value' in val:
+                    raise RuntimeError(f"{self.msginfo}: 'val' and 'value' at the same time, use "
+                                       "'val'.")
+                elif 'value' in val and not warned:
+                    warn_deprecation(f"{self.msginfo}: 'value' will be deprecated in 4.0. Please "
+                                     "use 'val' in the future.")
+
+                if 'value' in val:
+                    val['val'] = val.pop('value')
+                    warned = True
+
                 kwargs2[arg] = val.copy()
 
                 if units is not None:
@@ -347,22 +370,22 @@ class ExecComp(ExplicitComponent):
                                            "variable '%s', but shape of %s has been "
                                            "specified for the entire component." %
                                            (self.msginfo, val['shape'], arg, shape))
-                    elif 'value' in val and np.atleast_1d(val['value']).shape != shape:
+                    elif 'val' in val and np.atleast_1d(val['val']).shape != shape:
                         raise RuntimeError("%s: value of shape %s has been specified for "
                                            "variable '%s', but shape of %s has been "
                                            "specified for the entire component." %
-                                           (self.msginfo, np.atleast_1d(val['value']).shape,
+                                           (self.msginfo, np.atleast_1d(val['val']).shape,
                                             arg, shape))
                     else:
                         init_vals[arg] = np.ones(shape)
 
-                if 'value' in val:
-                    init_vals[arg] = val['value']
-                    del kwargs2[arg]['value']
+                if 'val' in val:
+                    init_vals[arg] = val['val']
+                    del kwargs2[arg]['val']
 
                 if shape_by_conn or 'shape_by_conn' in val or 'copy_shape' in val:
-                    if val.get('shape') is not None or val.get('value') is not None:
-                        raise RuntimeError(f"{self.msginfo}: Can't set 'shape' or 'value' for "
+                    if val.get('shape') is not None or val.get('val') is not None:
+                        raise RuntimeError(f"{self.msginfo}: Can't set 'shape' or 'val' for "
                                            f"variable '{arg}' along with 'copy_shape' or "
                                            "'shape_by_conn'.")
 
@@ -378,6 +401,11 @@ class ExecComp(ExplicitComponent):
             else:
                 init_vals[arg] = val
 
+        if self._static_mode:
+            var_rel2meta = self._static_var_rel2meta
+        else:
+            var_rel2meta = self._var_rel2meta
+
         for var in sorted(allvars):
             meta = kwargs2.get(var, {
                 'units': units,
@@ -390,19 +418,77 @@ class ExecComp(ExplicitComponent):
             else:
                 val = 1.0
 
-            if var in outs:
-                dct = self.add_output(var, val, **meta)
+            if var in var_rel2meta:
+                # Input/Output already exists, but we may be setting defaults for the first time.
+                # Note that there is only one submitted dictionary of defaults.
+                current_meta = var_rel2meta[var]
+
+                for kname, kvalue in meta.items():
+                    if kvalue is not None:
+                        current_meta[kname] = kvalue
+
+                new_val = kwargs[var].get('val')
+                if new_val is not None:
+                    current_meta['val'] = new_val
             else:
-                dct = self.add_input(var, val, **meta)
+                # new input and/or output.
+                if var in outs:
+                    current_meta = self.add_output(var, val, **meta)
+                else:
+                    current_meta = self.add_input(var, val, **meta)
 
             if var not in init_vals:
-                init_vals[var] = dct['value']
+                init_vals[var] = current_meta['val']
 
         self._codes = self._compile_exprs(self._exprs)
 
+    def add_expr(self, expr, **kwargs):
+        """
+        Add an expression to the ExecComp.
+
+        Parameters
+        ----------
+        expr : str
+            An assignment statement that expresses how the outputs are calculated based on the
+            inputs. In addition to standard Python operators, a subset of numpy and scipy
+            functions is supported.
+        **kwargs : dict of named args
+            Initial values of variables can be set by setting a named arg with the var name.  If
+            the value is a dict it is assumed to contain metadata.  To set the initial value in
+            addition to other metadata, assign the initial value to the 'val' entry of the dict.
+            Do not include for inputs whose default kwargs have been declared on previous
+            expressions.
+        """
+        if not isinstance(expr, str):
+            typ = type(expr).__name__
+            msg = f"Argument 'expr' must be of type 'str', but type '{typ}' was found."
+            raise TypeError(msg)
+
+        self._exprs.append(expr)
+        for name in kwargs:
+            if name in self._kwargs:
+                raise NameError(f"Defaults for '{name}' have already been defined in a previous "
+                                "expression.")
+
+        self._kwargs.update(kwargs)
+
+        if not self._static_mode:
+            self._setup_expressions()
+
     def _compile_exprs(self, exprs):
         compiled = []
+        outputs = []
         for i, expr in enumerate(exprs):
+
+            # Quick dupe check.
+            lhs_name = expr.split('=', 1)[0].strip()
+            if lhs_name in outputs:
+                # Can't add two equations with the same output.
+                raise RuntimeError(f"{self.msginfo}: The output '{lhs_name}' has already been "
+                                   "defined by an expression.")
+            else:
+                outputs.append(lhs_name)
+
             try:
                 compiled.append(compile(expr, expr, 'exec'))
             except Exception:
@@ -509,9 +595,9 @@ class ExecComp(ExplicitComponent):
                 for out in sorted(outs):
                     for inp in ins:
                         if self.options['has_diag_partials']:
-                            ival = meta[inp]['value']
+                            ival = meta[inp]['val']
                             iarray = isinstance(ival, ndarray) and ival.size > 1
-                            oval = meta[out]['value']
+                            oval = meta[out]['val']
                             if iarray and isinstance(oval, ndarray) and oval.size > 1:
                                 if oval.size != ival.size:
                                     raise RuntimeError(
@@ -519,7 +605,7 @@ class ExecComp(ExplicitComponent):
                                         "is not square (shape=(%d, %d))." %
                                         (self.msginfo, out, inp, oval.size, ival.size))
                                 # partial will be declared as diagonal
-                                inds = np.arange(oval.size, dtype=int)
+                                inds = np.arange(oval.size, dtype=INT_DTYPE)
                             else:
                                 inds = None
                             decl_partials(of=out, wrt=inp, rows=inds, cols=inds)
@@ -542,8 +628,9 @@ class ExecComp(ExplicitComponent):
                 idx = len(self.pathname) + 1 if self.pathname else 0
                 undeclared = ', '.join([' wrt '.join((f"'{of[idx:]}'", f"'{wrt[idx:]}'"))
                                         for of, wrt in undeclared])
-                simple_warning(f"{self.msginfo}: The following partial derivatives have not been "
-                               f"declared so they are assumed to be zero: [{undeclared}].")
+                issue_warning(f"The following partial derivatives have not been "
+                              f"declared so they are assumed to be zero: [{undeclared}].",
+                              prefix=self.msginfo, category=DerivativesWarning)
 
     def compute(self, inputs, outputs):
         """
@@ -577,7 +664,7 @@ class ExecComp(ExplicitComponent):
         """
         if self._requires_fd:
             if 'fd' in self._approx_schemes:
-                fdins = {tup[0].rsplit('.', 1)[1] for tup in self._approx_schemes['fd']._exec_dict}
+                fdins = {wrt.rsplit('.', 1)[1] for wrt in self._approx_schemes['fd']._wrt_meta}
             else:
                 fdins = set()
 
