@@ -10,6 +10,7 @@ from numpy.testing import assert_almost_equal
 import openmdao.api as om
 from openmdao.utils.assert_utils import assert_near_equal, assert_warning, assert_check_partials
 from openmdao.utils.general_utils import set_pyoptsparse_opt
+from openmdao.utils.testing_utils import use_tempdirs
 
 scipy_gte_019 = True
 try:
@@ -384,6 +385,7 @@ class SampleMap(object):
                        'values': g})
 
 
+@use_tempdirs
 @unittest.skipIf(not scipy_gte_019, "only run if scipy>=0.19.")
 class TestMetaModelStructuredScipy(unittest.TestCase):
     """
@@ -676,6 +678,7 @@ class TestMetaModelStructuredScipy(unittest.TestCase):
         self.assertEqual(str(cm.exception), msg)
 
 
+@use_tempdirs
 class TestMetaModelStructuredPython(unittest.TestCase):
     """
     Tests the regular grid map component. specifically the analytic derivatives
@@ -1128,13 +1131,12 @@ class TestMetaModelStructuredPython(unittest.TestCase):
             p.run_driver()
 
 
+@use_tempdirs
 @unittest.skipIf(not scipy_gte_019, "only run if scipy>=0.19.")
 class TestMetaModelStructuredCompFeature(unittest.TestCase):
 
     @unittest.skipIf(not scipy_gte_019, "only run if scipy>=0.19.")
     def test_xor(self):
-        import numpy as np
-        import openmdao.api as om
 
         # Create regular grid interpolator instance
         xor_interp = om.MetaModelStructuredComp(method='scipy_slinear')
@@ -1170,8 +1172,6 @@ class TestMetaModelStructuredCompFeature(unittest.TestCase):
 
     @unittest.skipIf(not scipy_gte_019, "only run if scipy>=0.19.")
     def test_shape(self):
-        import numpy as np
-        import openmdao.api as om
 
         # create input param training data, of sizes 25, 5, and 10 points resp.
         p1 = np.linspace(0, 100, 25)
@@ -1216,8 +1216,6 @@ class TestMetaModelStructuredCompFeature(unittest.TestCase):
 
     @unittest.skipIf(not scipy_gte_019, "only run if scipy>=0.19.")
     def test_vectorized(self):
-        import numpy as np
-        import openmdao.api as om
 
         # create input param training data, of sizes 25, 5, and 10 points resp.
         p1 = np.linspace(0, 100, 25)
@@ -1256,8 +1254,6 @@ class TestMetaModelStructuredCompFeature(unittest.TestCase):
 
     @unittest.skipIf(not scipy_gte_019, "only run if scipy>=0.19.")
     def test_training_derivatives(self):
-        import numpy as np
-        import openmdao.api as om
 
         # create input param training data, of sizes 25, 5, and 10 points resp.
         p1 = np.linspace(0, 100, 25)
