@@ -9,7 +9,8 @@ from openmdao.test_suite.components.expl_comp_array import TestExplCompArray
 from openmdao.test_suite.components.impl_comp_simple import TestImplCompSimple
 from openmdao.test_suite.components.impl_comp_array import TestImplCompArray
 from openmdao.utils.assert_utils import assert_near_equal, assert_warning
-from openmdao.warnings import OMDeprecationWarning
+from openmdao.utils.om_warnings import OMDeprecationWarning
+
 
 class TestExplicitComponent(unittest.TestCase):
 
@@ -293,6 +294,25 @@ class TestExplicitComponent(unittest.TestCase):
         # pretend we reconfigured
         prob.setup()
 
+    def test_value_getitem_deprecation(self):
+        comp = TestExplCompSimple()
+        prob = Problem(comp).setup()
+
+        # check optional metadata (desc)
+        msg = ("The metadata key 'value' will be deprecated in 4.0. Please use 'val'")
+
+        prob.setup()
+        with assert_warning(OMDeprecationWarning, msg):
+            comp._var_rel2meta['length']['value']
+
+    def test_return_metadata_value_deprecation(self):
+        prob = Problem()
+        idv = prob.model.add_subsystem('idv', IndepVarComp())
+        meta = idv.add_output('x', 1.0)
+
+        msg = ("The metadata key 'value' will be deprecated in 4.0. Please use 'val'")
+        with assert_warning(OMDeprecationWarning, msg):
+            meta['value']
 
 class TestImplicitComponent(unittest.TestCase):
 
@@ -362,8 +382,8 @@ class TestRangePartials(unittest.TestCase):
         prob = Problem(model=comp)
 
         with assert_warning(OMDeprecationWarning,
-                            f"<model> <class RangePartialsComp>: Passing `src_indices` as an arg to `add_input` is"
-                            "deprecated and will become an error in a future release.  Add "
+                            f"<model> <class RangePartialsComp>: Passing `src_indices` as an arg to `add_input('v1', ...` is"
+                            " deprecated and will become an error in a future release.  Add "
                             "`src_indices` to a `promotes` or `connect` call instead."):
             prob.setup()
 
