@@ -114,6 +114,48 @@ class QuadraticJacVec(QuadraticComp):
             d_residuals['x'] = self.inv_jac * d_outputs['x']
 
 
+class ImplCompTestCase(unittest.TestCase):
+
+    def test_add_input_output_retval(self):
+        # check basic metadata expected in return value
+        expected = {
+            'val': 3,
+            'shape': (1,),
+            'size': 1,
+            'units': 'ft',
+            'desc': '',
+            'tags': set(),
+        }
+        expected_discrete = {
+            'val': 3,
+            'type': int,
+            'desc': '',
+            'tags': set(),
+        }
+
+        class ImplComp(om.ImplicitComponent):
+            def setup(self):
+                meta = self.add_input('x', val=3.0, units='ft')
+                for key, val in expected.items():
+                    assert meta[key] == val, f'Expected {key}: {val} but got {key}: {meta[key]}'
+
+                meta = self.add_discrete_input('x_disc', val=3)
+                for key, val in expected_discrete.items():
+                    assert meta[key] == val, f'Expected {key}: {val} but got {key}: {meta[key]}'
+
+                meta = self.add_output('y', val=3.0, units='ft')
+                for key, val in expected.items():
+                    assert meta[key] == val, f'Expected {key}: {val} but got {key}: {meta[key]}'
+
+                meta = self.add_discrete_output('y_disc', val=3)
+                for key, val in expected_discrete.items():
+                    assert meta[key] == val, f'Expected {key}: {val} but got {key}: {meta[key]}'
+
+        prob = om.Problem()
+        prob.model.add_subsystem('comp', ImplComp())
+        prob.setup()
+
+
 class ImplicitCompTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -153,60 +195,60 @@ class ImplicitCompTestCase(unittest.TestCase):
         # cannot list_inputs on a Group before running
         model_inputs = self.prob.model.list_inputs(desc=True, out_stream=None)
         expected = {
-            'comp1.a': {'value': [1.], 'desc': ''},
-            'comp1.b': {'value': [1.], 'desc': ''},
-            'comp1.c': {'value': [1.], 'desc': ''},
-            'comp2.a': {'value': [1.], 'desc': ''},
-            'comp2.b': {'value': [1.], 'desc': ''},
-            'comp2.c': {'value': [1.], 'desc': ''},
+            'comp1.a': {'val': [1.], 'desc': ''},
+            'comp1.b': {'val': [1.], 'desc': ''},
+            'comp1.c': {'val': [1.], 'desc': ''},
+            'comp2.a': {'val': [1.], 'desc': ''},
+            'comp2.b': {'val': [1.], 'desc': ''},
+            'comp2.c': {'val': [1.], 'desc': ''},
         }
         self.assertEqual(dict(model_inputs), expected)
 
         # list_inputs on a component before running is okay
         c2_inputs = self.prob.model.comp2.list_inputs(desc=True, out_stream=None)
         expected = {
-            'a': {'value': [1.], 'desc': ''},
-            'b': {'value': [1.], 'desc': ''},
-            'c': {'value': [1.], 'desc': ''}
+            'a': {'val': [1.], 'desc': ''},
+            'b': {'val': [1.], 'desc': ''},
+            'c': {'val': [1.], 'desc': ''}
         }
         self.assertEqual(dict(c2_inputs), expected)
 
         # listing component inputs based on tags should work
         c2_inputs = self.prob.model.comp2.list_inputs(tags='tag_a', out_stream=None)
-        self.assertEqual(dict(c2_inputs), {'a': {'value': [1.]}})
+        self.assertEqual(dict(c2_inputs), {'a': {'val': [1.]}})
 
         # includes and excludes based on relative names should work
         c2_inputs = self.prob.model.comp2.list_inputs(includes='a', out_stream=None)
-        self.assertEqual(dict(c2_inputs), {'a': {'value': [1.]}})
+        self.assertEqual(dict(c2_inputs), {'a': {'val': [1.]}})
 
         c2_inputs = self.prob.model.comp2.list_inputs(excludes='c', out_stream=None)
         expected = {
-            'a': {'value': [1.]},
-            'b': {'value': [1.]},
+            'a': {'val': [1.]},
+            'b': {'val': [1.]},
         }
         self.assertEqual(dict(c2_inputs), expected)
 
         # specifying prom_name should not cause an error
         c2_inputs = self.prob.model.comp2.list_inputs(prom_name=True, out_stream=None)
         self.assertEqual(dict(c2_inputs), {
-            'a': {'value': [1.], 'prom_name': 'a'},
-            'b': {'value': [1.], 'prom_name': 'b'},
-            'c': {'value': [1.], 'prom_name': 'c'}
+            'a': {'val': [1.], 'prom_name': 'a'},
+            'b': {'val': [1.], 'prom_name': 'b'},
+            'c': {'val': [1.], 'prom_name': 'c'}
         })
 
     def test_list_outputs_before_run(self):
         # cannot list_outputs on a Group before running
         model_outputs = self.prob.model.list_outputs(out_stream=None)
         expected = {
-            'comp1.x': {'value': [0.]},
-            'comp2.x': {'value': [0.]},
+            'comp1.x': {'val': [0.]},
+            'comp2.x': {'val': [0.]},
         }
         self.assertEqual(dict(model_outputs), expected)
 
         # list_outputs on a component before running is okay
         c2_outputs = self.prob.model.comp2.list_outputs(out_stream=None)
         expected = {
-            'x': {'value': np.array([0.])}
+            'x': {'val': np.array([0.])}
         }
         self.assertEqual(dict(c2_outputs), expected)
 
@@ -225,13 +267,13 @@ class ImplicitCompTestCase(unittest.TestCase):
         # there are no residuals yet, so nothing should be filtered
         c2_outputs = self.prob.model.comp2.list_outputs(residuals_tol=.01, out_stream=None)
         self.assertEqual(dict(c2_outputs), {
-            'x': {'value': 0.}
+            'x': {'val': 0.}
         })
 
         # specifying prom_name should not cause an error
         c2_outputs = self.prob.model.comp2.list_outputs(prom_name=True, out_stream=None)
         self.assertEqual(dict(c2_outputs), {
-            'x': {'value': 0., 'prom_name': 'x'}
+            'x': {'val': 0., 'prom_name': 'x'}
         })
 
     def test_list_inputs(self):
@@ -240,17 +282,17 @@ class ImplicitCompTestCase(unittest.TestCase):
         stream = StringIO()
         inputs = self.prob.model.list_inputs(hierarchical=False, desc=True, out_stream=stream)
         self.assertEqual(sorted(inputs), [
-            ('comp1.a', {'value':  [1.], 'desc': ''}),
-            ('comp1.b', {'value': [-4.], 'desc': ''}),
-            ('comp1.c', {'value':  [3.], 'desc': ''}),
-            ('comp2.a', {'value':  [1.], 'desc': ''}),
-            ('comp2.b', {'value': [-4.], 'desc': ''}),
-            ('comp2.c', {'value':  [3.], 'desc': ''})
+            ('comp1.a', {'val':  [1.], 'desc': ''}),
+            ('comp1.b', {'val': [-4.], 'desc': ''}),
+            ('comp1.c', {'val':  [3.], 'desc': ''}),
+            ('comp2.a', {'val':  [1.], 'desc': ''}),
+            ('comp2.b', {'val': [-4.], 'desc': ''}),
+            ('comp2.c', {'val':  [3.], 'desc': ''})
         ])
         text = stream.getvalue()
         self.assertEqual(text.count('comp1.'), 3)
         self.assertEqual(text.count('comp2.'), 3)
-        self.assertEqual(text.count('value'), 1)
+        self.assertEqual(text.count('val'), 1)
 
     def test_list_inputs_with_tags(self):
         self.prob.run_model()
@@ -309,16 +351,16 @@ class ImplicitCompTestCase(unittest.TestCase):
         # No tags
         outputs = self.prob.model.list_outputs(explicit=False, hierarchical=False, out_stream=None)
         self.assertEqual(sorted(outputs), [
-            ('comp1.x', {'value': [3.]}),
-            ('comp2.x', {'value': [3.]}),
+            ('comp1.x', {'val': [3.]}),
+            ('comp2.x', {'val': [3.]}),
         ])
 
         # With tag
         outputs = self.prob.model.list_outputs(explicit=False, hierarchical=False, out_stream=None,
                                                tags="tag_x")
         self.assertEqual(sorted(outputs), [
-            ('comp1.x', {'value': [3.]}),
-            ('comp2.x', {'value': [3.]}),
+            ('comp1.x', {'val': [3.]}),
+            ('comp2.x', {'val': [3.]}),
         ])
 
         # Wrong tag
@@ -332,12 +374,12 @@ class ImplicitCompTestCase(unittest.TestCase):
         stream = StringIO()
         states = self.prob.model.list_outputs(explicit=False, residuals=True,
                                               hierarchical=False, out_stream=stream)
-        self.assertEqual([('comp1.x', {'value': [3.], 'resids': [0.]}),
-                          ('comp2.x', {'value': [3.], 'resids': [0.]})], sorted(states))
+        self.assertEqual([('comp1.x', {'val': [3.], 'resids': [0.]}),
+                          ('comp2.x', {'val': [3.], 'resids': [0.]})], sorted(states))
         text = stream.getvalue()
         self.assertEqual(1, text.count('comp1.x'))
         self.assertEqual(1, text.count('comp2.x'))
-        self.assertEqual(1, text.count('value'))
+        self.assertEqual(1, text.count('val'))
         self.assertEqual(1, text.count('resids'))
 
     def test_list_outputs_prom_name(self):
@@ -369,7 +411,7 @@ class ImplicitCompTestCase(unittest.TestCase):
         self.assertEqual(text.count('comp1.x'), 1)
         self.assertEqual(text.count('comp2.x'), 1)
         self.assertEqual(text.count('varname'), 1)
-        self.assertEqual(text.count('value'), 0)
+        self.assertEqual(text.count('val'), 0)
         self.assertEqual(text.count('resids'), 1)
 
     def test_list_residuals_with_tol(self):
@@ -407,7 +449,7 @@ class ImplicitCompTestCase(unittest.TestCase):
             "",
             "1 Implicit Output(s) in 'model'",
             "",
-            "varname  value         resids     ",
+            "varname  val           resids     ",
             "-------  ------------  -----------",
             "d2",
             "  y2",  # values removed from comparison
@@ -778,8 +820,6 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
         assert_near_equal(prob['sub.comp2.y'], 77., 1e-5)
 
     def test_guess_nonlinear_feature(self):
-        import openmdao.api as om
-        import numpy as np
 
         class ImpWithInitial(om.ImplicitComponent):
             """
@@ -1093,7 +1133,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_apply_linear(['linear'], 'fwd')
+            prob.model.run_apply_linear('fwd')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
@@ -1113,7 +1153,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_apply_linear(['linear'], 'fwd')
+            prob.model.run_apply_linear('fwd')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
@@ -1133,7 +1173,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_apply_linear(['linear'], 'fwd')
+            prob.model.run_apply_linear('fwd')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
@@ -1153,7 +1193,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_apply_linear(['linear'], 'fwd')
+            prob.model.run_apply_linear('fwd')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
@@ -1173,7 +1213,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_apply_linear(['linear'], 'rev')
+            prob.model.run_apply_linear('rev')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'x' in residual vector "
@@ -1192,7 +1232,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
         prob.run_model()
 
         with self.assertRaises(om.AnalysisError):
-            prob.model.run_apply_linear(['linear'], 'rev')
+            prob.model.run_apply_linear('rev')
 
         # verify read_only status is reset after AnalysisError
         prob['bad.a'] = 111.
@@ -1213,7 +1253,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_solve_linear(['linear'], 'rev')
+            prob.model.run_solve_linear('rev')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
@@ -1233,7 +1273,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 
         # check input vector
         with self.assertRaises(ValueError) as cm:
-            prob.model.run_solve_linear(['linear'], 'fwd')
+            prob.model.run_solve_linear('fwd')
 
         self.assertEqual(str(cm.exception),
                          "'bad' <class BadComp>: Attempt to set value of 'x' in residual vector "
@@ -1252,7 +1292,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
         prob.model.run_linearize()
 
         with self.assertRaises(om.AnalysisError):
-            prob.model.run_solve_linear(['linear'], 'fwd')
+            prob.model.run_solve_linear('fwd')
 
         # verify read_only status is reset after AnalysisError
         prob.model.bad._vectors['residual']['linear']['x'] = 111.
@@ -1261,8 +1301,6 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
 class ListFeatureTestCase(unittest.TestCase):
 
     def setUp(self):
-        import openmdao.api as om
-        from openmdao.core.tests.test_impl_comp import QuadraticComp
 
         group = om.Group()
 
@@ -1302,12 +1340,12 @@ class ListFeatureTestCase(unittest.TestCase):
         # list inputs
         inputs = prob.model.list_inputs(out_stream=None)
         self.assertEqual(sorted(inputs), [
-            ('sub.comp1.a', {'value': [1.]}),
-            ('sub.comp1.b', {'value': [-4.]}),
-            ('sub.comp1.c', {'value': [3.]}),
-            ('sub.comp2.a', {'value': [1.]}),
-            ('sub.comp2.b', {'value': [-4.]}),
-            ('sub.comp2.c', {'value': [3.]})
+            ('sub.comp1.a', {'val': [1.]}),
+            ('sub.comp1.b', {'val': [-4.]}),
+            ('sub.comp1.c', {'val': [3.]}),
+            ('sub.comp2.a', {'val': [1.]}),
+            ('sub.comp2.b', {'val': [-4.]}),
+            ('sub.comp2.c', {'val': [3.]})
         ])
 
     def test_for_docs_list_no_values(self):
@@ -1339,42 +1377,6 @@ class ListFeatureTestCase(unittest.TestCase):
         ])
 
     def test_simple_list_vars_options(self):
-        import openmdao.api as om
-
-        class QuadraticComp(om.ImplicitComponent):
-            """
-            A Simple Implicit Component representing a Quadratic Equation.
-
-            R(a, b, c, x) = ax^2 + bx + c
-
-            Solution via Quadratic Formula:
-            x = (-b + sqrt(b^2 - 4ac)) / 2a
-            """
-
-            def setup(self):
-                self.add_input('a', val=1., units='ft')
-                self.add_input('b', val=1., units='inch')
-                self.add_input('c', val=1., units='ft')
-                self.add_output('x', val=0.,
-                                lower=1.0, upper=100.0,
-                                ref=1.1, ref0=2.1,
-                                units='inch')
-
-            def setup_partials(self):
-                self.declare_partials(of='*', wrt='*')
-
-            def apply_nonlinear(self, inputs, outputs, residuals):
-                a = inputs['a']
-                b = inputs['b']
-                c = inputs['c']
-                x = outputs['x']
-                residuals['x'] = a * x ** 2 + b * x + c
-
-            def solve_nonlinear(self, inputs, outputs):
-                a = inputs['a']
-                b = inputs['b']
-                c = inputs['c']
-                outputs['x'] = (-b + (b ** 2 - 4 * a * c) ** 0.5) / (2 * a)
 
         group = om.Group()
 
@@ -1427,21 +1429,19 @@ class ListFeatureTestCase(unittest.TestCase):
         outputs = prob.model.list_outputs(explicit=False, out_stream=None)
         text = stream.getvalue()
         self.assertEqual(sorted(outputs), [
-            ('sub.comp2.x', {'value': [3.]}),
-            ('sub.comp3.x', {'value': [3.]})
+            ('sub.comp2.x', {'val': [3.]}),
+            ('sub.comp3.x', {'val': [3.]})
         ])
         # list explicit outputs
         stream = StringIO()
         outputs = prob.model.list_outputs(implicit=False, out_stream=None)
         self.assertEqual(sorted(outputs), [
-            ('comp1.a', {'value': [1.]}),
-            ('comp1.b', {'value': [-4.]}),
-            ('comp1.c', {'value': [3.]}),
+            ('comp1.a', {'val': [1.]}),
+            ('comp1.b', {'val': [-4.]}),
+            ('comp1.c', {'val': [3.]}),
         ])
 
     def test_list_residuals_with_tol(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarImplicitDis1, SellarImplicitDis2
         prob = om.Problem()
         model = prob.model
 
@@ -1462,7 +1462,6 @@ class ListFeatureTestCase(unittest.TestCase):
         prob.run_model()
 
         outputs = model.list_outputs(residuals_tol=0.01, residuals=True)
-        print(outputs)
 
 
 class CacheUsingComp(om.ImplicitComponent):
