@@ -6,7 +6,7 @@ import numpy as np
 
 from openmdao.api import Problem, Group, IndepVarComp, ExecComp, ExplicitComponent
 from openmdao.utils.assert_utils import assert_near_equal, assert_warning
-from openmdao.warnings import OMDeprecationWarning
+from openmdao.utils.om_warnings import OMDeprecationWarning
 
 
 class TestSystem(unittest.TestCase):
@@ -31,7 +31,7 @@ class TestSystem(unittest.TestCase):
                          "<class Group>: Cannot get vectors because setup has not yet been called.")
 
         with self.assertRaises(Exception) as cm:
-            d_inputs, d_outputs, d_residuals = model.get_linear_vectors('vec')
+            d_inputs, d_outputs, d_residuals = model.get_linear_vectors()
         self.assertEqual(str(cm.exception),
                          "<class Group>: Cannot get vectors because setup has not yet been called.")
 
@@ -76,16 +76,10 @@ class TestSystem(unittest.TestCase):
         self.assertEqual(residuals['G1.G2.C1.b'], 99.0)
 
         # Test linear
-        d_inputs, d_outputs, d_residuals = model.get_linear_vectors('linear')
+        d_inputs, d_outputs, d_residuals = model.get_linear_vectors()
         d_outputs['G1.G2.C1.b'] = 10.
         self.assertEqual(d_outputs['G1.G2.C1.b'], 10.)
 
-        # Test linear with invalid vec_name
-        with self.assertRaises(Exception) as cm:
-            d_inputs, d_outputs, d_residuals = model.get_linear_vectors('bad_name')
-        self.assertEqual(str(cm.exception),
-                         "<model> <class Group>: There is no linear vector named %s" % 'bad_name')
-
     def test_set_checks_shape(self):
         indep = IndepVarComp()
         indep.add_output('a')
@@ -257,6 +251,47 @@ class TestSystem(unittest.TestCase):
         outputs = model.list_outputs(excludes=['circuit*'], implicit=False, out_stream=None)
         self.assertEqual(len(outputs), 2)
 
+    def test_list_inputs_outputs_val_deprecation(self):
+        p = Problem()
+        p.model.add_subsystem('comp', ExecComp('b=2*a'), promotes=['a', 'b'])
+        p.setup()
+        p.run_model()
+
+        msg = "<model> <class Group>: The 'values' argument to 'list_inputs()' " \
+              "is deprecated and will be removed in 4.0. Please use 'val' instead."
+
+        with assert_warning(OMDeprecationWarning, msg):
+            inputs = p.model.list_inputs(values=False, out_stream=None)
+        self.assertEqual(inputs, [('comp.a', {})])
+
+        with assert_warning(OMDeprecationWarning, msg):
+            inputs = p.model.list_inputs(values=True, out_stream=None)
+        self.assertEqual(inputs, [('comp.a', {'val': 1})])
+
+        msg = "The metadata key 'value' will be deprecated in 4.0. Please use 'val'"
+        with assert_warning(OMDeprecationWarning, msg):
+            self.assertEqual(inputs[0][1]['value'], 1)
+
+        msg = "<model> <class Group>: The 'values' argument to 'list_outputs()' " \
+              "is deprecated and will be removed in 4.0. Please use 'val' instead."
+
+        with assert_warning(OMDeprecationWarning, msg):
+            outputs = p.model.list_outputs(values=False, out_stream=None)
+        self.assertEqual(outputs, [('comp.b', {})])
+
+        with assert_warning(OMDeprecationWarning, msg):
+            outputs = p.model.list_outputs(values=True, out_stream=None)
+        self.assertEqual(outputs, [('comp.b', {'val': 2})])
+
+        msg = "The metadata key 'value' will be deprecated in 4.0. Please use 'val'"
+        with assert_warning(OMDeprecationWarning, msg):
+            self.assertEqual(outputs[0][1]['value'], 2)
+
+        meta = p.model.get_io_metadata(metadata_keys=('val',))
+        with assert_warning(OMDeprecationWarning, msg):
+            self.assertEqual(meta['comp.a']['value'], 1)
+
+
     def test_recording_options_deprecated(self):
         prob = Problem()
         msg = "The recording option, record_model_metadata, on System is deprecated. " \
