@@ -27,7 +27,7 @@ from openmdao.core.driver import Driver
 from openmdao.core.system import System
 from openmdao.core.problem import Problem
 from openmdao.solvers.solver import Solver
-from openmdao.warnings import issue_warning, CaseRecorderWarning
+from openmdao.utils.om_warnings import issue_warning, CaseRecorderWarning
 
 
 """
@@ -145,6 +145,8 @@ class SqliteRecorder(CaseRecorder):
         Path to the recorder file.
     _database_initialized : bool
         Flag indicating whether or not the database has been initialized.
+    _started : set
+        set of recording requesters for which this recorder has been started.
     _record_on_proc : bool
         Flag indicating whether to record on this processor when running in parallel.
     """
@@ -178,6 +180,7 @@ class SqliteRecorder(CaseRecorder):
         self._pickle_version = pickle_version
         self._filepath = filepath
         self._database_initialized = False
+        self._started = set()
 
         # default to record on all procs when running in parallel
         self._record_on_proc = True
@@ -198,6 +201,13 @@ class SqliteRecorder(CaseRecorder):
                 if rank == 0:
                     metadata_filepath = f'{self._filepath}_meta'
                     print(f"Note: Metadata is being recorded separately as {metadata_filepath}.")
+                    try:
+                        os.remove(metadata_filepath)
+                        issue_warning('The existing case recorder metadata file, '
+                                      f'{metadata_filepath}, is being overwritten.',
+                                      category=UserWarning)
+                    except OSError:
+                        pass
                     self.metadata_connection = sqlite3.connect(metadata_filepath)
                 else:
                     self._record_metadata = False
@@ -211,6 +221,8 @@ class SqliteRecorder(CaseRecorder):
         if filepath:
             try:
                 os.remove(filepath)
+                issue_warning(f'The existing case recorder file, {filepath},'
+                              ' is being overwritten.', category=UserWarning)
             except OSError:
                 pass
 
@@ -303,24 +315,28 @@ class SqliteRecorder(CaseRecorder):
         recording_requester : object
             Object to which this recorder is attached.
         """
+        # we only want to set up recording once for each recording_requester
+        if recording_requester in self._started:
+            return
+
         super().startup(recording_requester)
 
         if not self._database_initialized:
             self._initialize_database()
 
-        driver = None
-
-        # grab the system
+        # grab the system and driver
         if isinstance(recording_requester, Driver):
             system = recording_requester._problem().model
             driver = recording_requester
         elif isinstance(recording_requester, System):
             system = recording_requester
+            driver = None
         elif isinstance(recording_requester, Problem):
             system = recording_requester.model
             driver = recording_requester.driver
         elif isinstance(recording_requester, Solver):
             system = recording_requester._system()
+            driver = None
         else:
             raise ValueError('Driver encountered a recording_requester it cannot handle'
                              ': {0}'.format(recording_requester))
@@ -340,20 +356,16 @@ class SqliteRecorder(CaseRecorder):
                     else:
                         objectives[name] = data
             else:
-                desvars = driver._designvars
-                constraints = driver._cons
-                objectives = driver._objs
-                responses = driver._responses
+                desvars = driver._designvars.copy()
+                constraints = driver._cons.copy()
+                objectives = driver._objs.copy()
+                responses = driver._responses.copy()
 
             inputs = list(system.abs_name_iter('input', local=False, discrete=True))
             outputs = list(system.abs_name_iter('output', local=False, discrete=True))
 
             var_order = system._get_vars_exec_order(inputs=True, outputs=True)
 
-            full_var_set = [(outputs, 'output'),
-                            (desvars, 'desvar'), (responses, 'response'),
-                            (objectives, 'objective'), (constraints, 'constraint')]
-
             # merge current abs2prom and prom2abs with this system's version
             self._abs2prom['input'].update(system._var_allprocs_abs2prom['input'])
             self._abs2prom['output'].update(system._var_allprocs_abs2prom['output'])
@@ -375,6 +387,10 @@ class SqliteRecorder(CaseRecorder):
             disc_meta_in = system._var_allprocs_discrete['input']
             disc_meta_out = system._var_allprocs_discrete['output']
 
+            full_var_set = [(outputs, 'output'),
+                            (desvars, 'desvar'), (responses, 'response'),
+                            (objectives, 'objective'), (constraints, 'constraint')]
+
             for var_set, var_type in full_var_set:
                 for name in var_set:
 
@@ -432,6 +448,8 @@ class SqliteRecorder(CaseRecorder):
                               "abs2prom=?, prom2abs=?, abs2meta=?, var_settings=?, conns=?",
                               (abs2prom, prom2abs, abs2meta, var_settings_json, conns))
 
+        self._started.add(recording_requester)
+
     def record_iteration_driver(self, driver, data, metadata):
         """
         Record data and metadata from a Driver.
@@ -445,6 +463,12 @@ class SqliteRecorder(CaseRecorder):
         metadata : dict
             Dictionary containing execution metadata.
         """
+        if not self._database_initialized:
+            raise RuntimeError(f"{driver.msginfo} attempted to record iteration to "
+                               f"'{self._filepath}', but database is not initialized;"
+                               " `run_model()`, `run_driver()`, or `final_setup()` "
+                               "must be called after adding a recorder.")
+
         if self.connection:
             outputs = data['output']
             inputs = data['input']
@@ -487,6 +511,12 @@ class SqliteRecorder(CaseRecorder):
         metadata : dict
             Dictionary containing execution metadata.
         """
+        if not self._database_initialized:
+            raise RuntimeError(f"{problem.msginfo} attempted to record iteration to "
+                               f"'{self._filepath}', but database is not initialized;"
+                               " `run_model()`, `run_driver()`, or `final_setup()` "
+                               "must be called after adding a recorder.")
+
         if self.connection:
             outputs = data['output']
             inputs = data['input']
@@ -543,6 +573,12 @@ class SqliteRecorder(CaseRecorder):
         metadata : dict
             Dictionary containing execution metadata.
         """
+        if not self._database_initialized:
+            raise RuntimeError(f"{system.msginfo} attempted to record iteration to "
+                               f"'{self._filepath}', but database is not initialized;"
+                               " `run_model()`, `run_driver()`, or `final_setup()` "
+                               "must be called after adding a recorder.")
+
         if self.connection:
             inputs = data['input']
             outputs = data['output']
@@ -588,6 +624,12 @@ class SqliteRecorder(CaseRecorder):
         metadata : dict
             Dictionary containing execution metadata.
         """
+        if not self._database_initialized:
+            raise RuntimeError(f"{solver.msginfo} attempted to record iteration to "
+                               f"'{self._filepath}', but database is not initialized;"
+                               " `run_model()`, `run_driver()`, or `final_setup()` "
+                               "must be called after adding a recorder.")
+
         if self.connection:
             abs = data['abs']
             rel = data['rel']
