@@ -87,6 +87,23 @@ class TestDirectSolver(LinearSolverTests.LinearSolverTestCase):
 
     linear_solver_class = om.DirectSolver
 
+    def test_specify_solver(self):
+
+        prob = om.Problem()
+        model = prob.model = SellarDerivatives()
+
+        model.linear_solver = om.DirectSolver()
+
+        prob.setup()
+        prob.run_model()
+
+        wrt = ['z']
+        of = ['obj']
+
+        J = prob.compute_totals(of=of, wrt=wrt, return_format='flat_dict')
+        assert_near_equal(J['obj', 'z'][0][0], 9.61001056, .00001)
+        assert_near_equal(J['obj', 'z'][0][1], 1.78448534, .00001)
+
     # DirectSolver doesn't iterate.
     def test_solve_linear_maxiter(self):
         # Test that using options that should not exist in class cause an error
@@ -127,7 +144,7 @@ class TestDirectSolver(LinearSolverTests.LinearSolverTestCase):
         d_outputs.set_val(0.0)
         g1._linearize(g1._assembled_jac)
         g1.linear_solver._linearize()
-        g1.run_solve_linear(['linear'], 'fwd')
+        g1.run_solve_linear('fwd')
 
         output = d_outputs.asarray()
         assert_near_equal(output, g1.expected_solution, 1e-15)
@@ -138,7 +155,7 @@ class TestDirectSolver(LinearSolverTests.LinearSolverTestCase):
         d_outputs.set_val(1.0)
         d_residuals.set_val(0.0)
         g1.linear_solver._linearize()
-        g1.run_solve_linear(['linear'], 'rev')
+        g1.run_solve_linear('rev')
 
         output = d_residuals.asarray()
         assert_near_equal(output, g1.expected_solution, 3e-15)
@@ -945,30 +962,6 @@ class TestDirectSolverRemoteErrors(unittest.TestCase):
         self.assertEqual(str(cm.exception), msg)
 
 
-
-class TestDirectSolverFeature(unittest.TestCase):
-
-    def test_specify_solver(self):
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
-
-        prob = om.Problem()
-        model = prob.model = SellarDerivatives()
-
-        model.linear_solver = om.DirectSolver()
-
-        prob.setup()
-        prob.run_model()
-
-        wrt = ['z']
-        of = ['obj']
-
-        J = prob.compute_totals(of=of, wrt=wrt, return_format='flat_dict')
-        assert_near_equal(J['obj', 'z'][0][0], 9.61001056, .00001)
-        assert_near_equal(J['obj', 'z'][0][1], 1.78448534, .00001)
-
-
 class TestDirectSolverMPI(unittest.TestCase):
 
     N_PROCS = 2
