@@ -3,7 +3,7 @@
 import os
 import unittest
 import openmdao.api as om
-from openmdao.visualization.n2_viewer.n2_viewer import _get_viewer_data, n2
+from openmdao.visualization.n2_viewer.n2_viewer import n2
 from openmdao.utils.mpi import MPI
 
 try:
@@ -15,18 +15,17 @@ except ImportError:
 DEBUG = False
 OUTFILE = 'n2test.html'
 
+
 # Test model derived from one contributed by Anil Yildirim at U-Mich MDO lab
 class myComp(om.ExplicitComponent):
-    def initialize(self):
-        self.options['distributed'] = True
-
     def setup(self):
-        self.add_input('x2')
-        self.add_output('x3', shape=MPI.COMM_WORLD.rank)
+        self.add_input('x2', distributed=True)
+        self.add_output('x3', shape=MPI.COMM_WORLD.rank, distributed=True)
 
     def compute(self, inputs, outputs):
         outputs['x3'] = inputs['x2'] + 1
 
+
 class Top(om.Group):
     def setup(self):
 
@@ -37,6 +36,7 @@ class Top(om.Group):
 
         self.connect('indep_var.x1', 'myComp.x2')
 
+
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class N2ParallelTestCase(unittest.TestCase):
     N_PROCS = 2
